@@ -350,7 +350,9 @@ class MaterializatonClientV2(ClientBase):
             md["expires_on"] = convert_timestamp(md["expires_on"])
         return d
 
-    def get_table_metadata(self, table_name: str, datastack_name=None, version: int= None):
+    def get_table_metadata(
+        self, table_name: str, datastack_name=None, version: int = None
+    ):
         """Get metadata about a table
 
         Parameters
@@ -379,8 +381,12 @@ class MaterializatonClientV2(ClientBase):
         url = self._endpoints["metadata"].format_map(endpoint_mapping)
 
         response = self.session.get(url)
-        self.raise_for_status(response)
-        return response.json()
+        metadata_d = handle_response(response)
+        vx = metadata_d.pop("voxel_resolution_x", None)
+        vy = metadata_d.pop("voxel_resolution_y", None)
+        vz = metadata_d.pop("voxel_resolution_z", None)
+        metadata_d["voxel_resolution"] = [vx, vy, vz]
+        return metadata_d
 
     # def get_annotation(self, table_name, annotation_ids,
     #                    materialization_version=None,
@@ -435,6 +441,7 @@ class MaterializatonClientV2(ClientBase):
         filter_in_dict,
         filter_out_dict,
         filter_equal_dict,
+        filter_spatial_dict,
         return_pyarrow,
         split_positions,
         offset,
@@ -460,6 +467,8 @@ class MaterializatonClientV2(ClientBase):
             data["filter_notin_dict"] = filter_out_dict
         if filter_equal_dict is not None:
             data["filter_equal_dict"] = filter_equal_dict
+        if filter_spatial_dict is not None:
+            data["filter_spatial_dict"] = filter_spatial_dict
         if select_columns is not None:
             data["select_columns"] = select_columns
         if offset is not None:
@@ -482,7 +491,7 @@ class MaterializatonClientV2(ClientBase):
         filter_in_dict=None,
         filter_out_dict=None,
         filter_equal_dict=None,
-        filter_spatial=None,
+        filter_spatial_dict=None,
         join_args=None,
         select_columns=None,
         offset: int = None,
@@ -507,6 +516,10 @@ class MaterializatonClientV2(ClientBase):
             filter_equal_dict (dict, optional):
                 inner layer: keys are column names, values are specified entry.
                 Defaults to None.
+            filter_spatial (dict, optional):
+                inner layer: keys are column names, values are bounding boxes
+                             as [[min_x, min_y,min_z],[max_x, max_y, max_z]]
+                             Expressed in units of the voxel_resolution of this dataset.
             offset (int, optional): offset in query result
             limit (int, optional): maximum results to return (server will set upper limit, see get_server_config)
             select_columns (list of str, optional): columns to select. Defaults to None.
@@ -537,7 +550,7 @@ class MaterializatonClientV2(ClientBase):
                     filter_in_dict=filter_in_dict,
                     filter_out_dict=filter_out_dict,
                     filter_equal_dict=filter_equal_dict,
-                    filter_spatial=filter_spatial,
+                    filter_spatial_dict=filter_spatial_dict,
                     join_args=join_args,
                     select_columns=select_columns,
                     offset=offset,
@@ -560,6 +573,7 @@ class MaterializatonClientV2(ClientBase):
             {table: filter_in_dict} if filter_in_dict is not None else None,
             {table: filter_out_dict} if filter_out_dict is not None else None,
             {table: filter_equal_dict} if filter_equal_dict is not None else None,
+            {table: filter_spatial_dict} if filter_spatial_dict is not None else None,
             return_df,
             True,
             offset,
@@ -577,6 +591,7 @@ class MaterializatonClientV2(ClientBase):
         if return_df:
             with warnings.catch_warnings():
                 warnings.simplefilter(action="ignore", category=FutureWarning)
+                warnings.simplefilter(action="ignore", category=DeprecationWarning)
                 df = pa.deserialize(response.content)
             if split_positions:
                 return df
@@ -591,7 +606,7 @@ class MaterializatonClientV2(ClientBase):
         filter_in_dict=None,
         filter_out_dict=None,
         filter_equal_dict=None,
-        filter_spatial=None,
+        filter_spatial_dict=None,
         join_args=None,
         select_columns=None,
         offset: int = None,
@@ -620,6 +635,12 @@ class MaterializatonClientV2(ClientBase):
                 outer layer: keys are table names
                 inner layer: keys are column names, values are specified entry.
                 Defaults to None.
+            filter_spatial (dict of dicts, optional):
+                outer layer: keys are table names:
+                inner layer: keys are column names, values are bounding boxes
+                             as [[min_x, min_y,min_z],[max_x, max_y, max_z]]
+                             Expressed in units of the voxel_resolution of this dataset.
+                Defaults to None
             select_columns (list of str, optional): columns to select. Defaults to None.
             offset (int, optional): result offset to use. Defaults to None.
                 will only return top K results.
@@ -652,6 +673,7 @@ class MaterializatonClientV2(ClientBase):
             filter_in_dict,
             filter_out_dict,
             filter_equal_dict,
+            filter_spatial_dict,
             return_df,
             True,
             offset,
@@ -669,6 +691,7 @@ class MaterializatonClientV2(ClientBase):
         if return_df:
             with warnings.catch_warnings():
                 warnings.simplefilter(action="ignore", category=FutureWarning)
+                warnings.simplefilter(action="ignore", category=DeprecationWarning)
                 df = pa.deserialize(response.content)
 
             if split_positions:
@@ -753,6 +776,11 @@ class MaterializatonClientV2(ClientBase):
         # with the most up to date get roots
         if len(future_map) == 0:
             future_map = None
+
+        if future_map is not None:
+            # pyarrow can make dataframes read only. Copying resets that.
+            df = df.copy()
+
         sv_columns = [c for c in df.columns if c.endswith("supervoxel_id")]
         with TimeIt("is_latest_roots"):
             all_root_ids = np.empty(0, dtype=np.int64)
@@ -763,7 +791,6 @@ class MaterializatonClientV2(ClientBase):
                 root_id_col = sv_col[: -len("supervoxel_id")] + "root_id"
                 # use the future map to update rootIDs
                 if future_map is not None:
-                    df[root_id_col] = df[root_id_col].copy()
                     df[root_id_col].replace(future_map, inplace=True)
                 all_root_ids = np.append(all_root_ids, df[root_id_col].values.copy())
 
@@ -828,7 +855,7 @@ class MaterializatonClientV2(ClientBase):
         filter_in_dict=None,
         filter_out_dict=None,
         filter_equal_dict=None,
-        filter_spatial=None,
+        filter_spatial_dict=None,
         join_args=None,
         select_columns=None,
         offset: int = None,
@@ -852,6 +879,11 @@ class MaterializatonClientV2(ClientBase):
             filter_equal_dict (dict, optional):
                 inner layer: keys are column names, values are specified entry.
                 Defaults to None.
+            filter_spatial (dict, optional):
+                inner layer: keys are column names, values are bounding boxes
+                             as [[min_x, min_y,min_z],[max_x, max_y, max_z]]
+                             Expressed in units of the voxel_resolution of this dataset.
+                             Defaults to None
             offset (int, optional): offset in query result
             limit (int, optional): maximum results to return (server will set upper limit, see get_server_config)
             select_columns (list of str, optional): columns to select. Defaults to None.
@@ -939,6 +971,9 @@ class MaterializatonClientV2(ClientBase):
                 if past_filter_out_dict is not None
                 else None,
                 {table: past_equal_dict} if past_equal_dict is not None else None,
+                {table: filter_spatial_dict}
+                if filter_spatial_dict is not None
+                else None,
                 True,
                 True,
                 offset,
@@ -963,6 +998,7 @@ class MaterializatonClientV2(ClientBase):
         with TimeIt("deserialize"):
             with warnings.catch_warnings():
                 warnings.simplefilter(action="ignore", category=FutureWarning)
+                warnings.simplefilter(action="ignore", category=DeprecationWarning)
                 df = pa.deserialize(response.content)
             if not split_positions:
                 concatenate_position_columns(df, inplace=True)
@@ -990,6 +1026,8 @@ class MaterializatonClientV2(ClientBase):
         self,
         pre_ids: Union[int, Iterable, np.ndarray] = None,
         post_ids: Union[int, Iterable, np.ndarray] = None,
+        bounding_box=None,
+        bounding_box_column: str = "post_pt_position",
         timestamp: datetime = None,
         remove_autapses: bool = True,
         include_zeros: bool = True,
@@ -1007,6 +1045,9 @@ class MaterializatonClientV2(ClientBase):
             post_ids (Union[int, Iterable, optional): post synaptic cell(s) to query. Defaults to None.
             timestamp (datetime.datetime, optional): timestamp to query (optional).
                 If passed recalculate query at timestamp, do not pass with materialization_verison
+            bounding_box: [[min_x, min_y, min_z],[max_x, max_y, max_z]] bounding box to filter
+                          synapse locations. Expressed in units of the voxel_resolution of this dataset (optional)
+            bounding_box_column (str, optional): which synapse location column to filter by (Default to "post_pt_position")
             remove_autapses (bool, optional): post-hoc filter out synapses. Defaults to True.
             include_zeros (bool, optional): whether to include synapses to/from id=0 (out of segmentation). Defaults to True.
             limit (int, optional): number of synapses to limit, Defaults to None (server side limit applies)
@@ -1022,6 +1063,7 @@ class MaterializatonClientV2(ClientBase):
         filter_equal_dict = {}
         filter_out_dict = None
         filter_equal_dict = {}
+        filter_spatial_dict = None
         if synapse_table is None:
             if self.synapse_table is None:
                 raise ValueError(
@@ -1043,12 +1085,15 @@ class MaterializatonClientV2(ClientBase):
                 filter_in_dict["post_pt_root_id"] = post_ids
             else:
                 filter_equal_dict["post_pt_root_id"] = post_ids
-        print(filter_in_dict, filter_equal_dict, filter_out_dict)
+        if bounding_box is not None:
+            filter_spatial_dict = {bounding_box_column: bounding_box}
+
         df = self.query_table(
             synapse_table,
             filter_in_dict=filter_in_dict,
             filter_out_dict=filter_out_dict,
             filter_equal_dict=filter_equal_dict,
+            filter_spatial_dict=filter_spatial_dict,
             offset=offset,
             limit=limit,
             split_positions=split_positions,
